SELECT count(1) AS `count`
FROM star1 t0